==> fred-ferda-3.15.0.tar.gz: fred-ferda-3.15.0/ferda/views/ajax/domain.py <==
"""Domain related ajax views."""
from datetime import datetime
from typing import Dict, Optional, Union, cast
from uuid import UUID

from django.contrib.auth.mixins import LoginRequiredMixin, PermissionRequiredMixin

from ferda.backend import BACKEND
from ferda.backend.exceptions import DomainDoesNotExist
from ferda.constants import LogEntryType

from .common import AbstractAuthInfoView, AbstractInfoView, AbstractStateHistoryView, AbstractStateView


class DomainAuthInfoView(LoginRequiredMixin, PermissionRequiredMixin, AbstractAuthInfoView):
    """Domain AuthInfo view."""

    permission_required = (
        'ferda.can_view_registry',
        'ferda.can_view_authinfo',
    )

    log_entry_type = LogEntryType.DOMAIN_AUTH_INFO
    log_entry_reference_name = 'domain'
    object_does_not_exist_exception = DomainDoesNotExist

    def get_object_auth_info(self, object_id: UUID, history_id: Union[UUID, datetime] = None) -> Optional[str]:
        """Get domain AuthInfo."""
        if isinstance(history_id, datetime):
            domain_history = BACKEND.get_domain_history(domain_id=object_id, start=history_id, end=history_id)
            history_id = cast(UUID, domain_history['timeline'][0]['domain_history_id'])
        return BACKEND.get_domain_info(domain_id=object_id, history_id=history_id).get('auth_info', None)


class DomainStateView(LoginRequiredMixin, PermissionRequiredMixin, AbstractStateView):
    """Domain state view."""

    permission_required = 'ferda.can_view_registry'

    log_entry_type = LogEntryType.DOMAIN_STATE
    log_entry_reference_name = 'domain'
    object_does_not_exist_exception = DomainDoesNotExist

    def get_object_state(self, object_id: UUID) -> Dict[str, bool]:
        """Get domain state."""
        return BACKEND.get_domain_state(domain_id=object_id)


class DomainInfoView(LoginRequiredMixin, PermissionRequiredMixin, AbstractInfoView):
    """Domain info view."""

    permission_required = 'ferda.can_view_registry'

    log_entry_type = LogEntryType.DOMAIN_DETAIL
    log_entry_reference_name = 'domain'
    object_does_not_exist_exception = DomainDoesNotExist

    def get_object_info(self, object_id: UUID, history_id: Union[UUID, datetime] = None) -> dict:
        """Get domain info."""
        if history_id is not None:
            assert isinstance(history_id, UUID)
        return BACKEND.get_domain_info(domain_id=object_id, history_id=history_id)


class DomainStateHistoryView(LoginRequiredMixin, PermissionRequiredMixin, AbstractStateHistoryView):
    """Domain state history view."""

    permission_required = 'ferda.can_view_registry'

    log_entry_type = LogEntryType.DOMAIN_STATE
    log_entry_reference_name = 'domain'
    object_does_not_exist_exception = DomainDoesNotExist

    def get_object_state_history(self, object_id: UUID) -> dict:
        """Get domain state history."""
        return BACKEND.get_domain_state_history(domain_id=object_id)

==> fred-ferda-3.22.1.tar.gz: fred-ferda-3.22.1/ferda/views/ajax/domain.py <==
"""Domain related ajax views."""
from datetime import datetime
from typing import Dict, Optional, Union
from uuid import UUID

from django.contrib.auth.mixins import LoginRequiredMixin, PermissionRequiredMixin

from ferda.backend import BACKEND
from ferda.backend.exceptions import DomainDoesNotExist
from ferda.constants import LogEntryType

from .common import AbstractInfoView, AbstractStateHistoryView, AbstractStateView


class DomainStateView(LoginRequiredMixin, PermissionRequiredMixin, AbstractStateView):
    """Domain state view."""

    permission_required = "ferda.can_view_registry"

    log_entry_type = LogEntryType.DOMAIN_STATE
    log_entry_reference_name = "domain"
    object_does_not_exist_exception = DomainDoesNotExist

    def get_object_state(self, object_id: UUID) -> Dict[str, bool]:
        """Get domain state."""
        return BACKEND.get_domain_state(domain_id=object_id)


class DomainInfoView(LoginRequiredMixin, PermissionRequiredMixin, AbstractInfoView):
    """Domain info view."""

    permission_required = "ferda.can_view_registry"

    log_entry_type = LogEntryType.DOMAIN_DETAIL
    log_entry_reference_name = "domain"
    object_does_not_exist_exception = DomainDoesNotExist

    def get_object_info(self, object_id: UUID, history_id: Optional[Union[UUID, datetime]] = None) -> dict:
        """Get domain info."""
        if history_id is not None:
            assert isinstance(history_id, UUID)
        return BACKEND.get_domain_info(domain_id=object_id, history_id=history_id)


class DomainStateHistoryView(LoginRequiredMixin, PermissionRequiredMixin, AbstractStateHistoryView):
    """Domain state history view."""

    permission_required = "ferda.can_view_registry"

    log_entry_type = LogEntryType.DOMAIN_STATE
    log_entry_reference_name = "domain"
    object_does_not_exist_exception = DomainDoesNotExist

    def get_object_state_history(self, object_id: UUID) -> dict:
        """Get domain state history."""
        return BACKEND.get_domain_state_history(domain_id=object_id)
